@@ -1,6 +1,10 @@
 import streamlit as st
 from streamlit_toggle import st_toggle_switch
 
+from .. import extra
+
+st_toggle_switch = extra(st_toggle_switch)
+
 
 def example():
     st.write("## Toggle Switch")
@@ -15,15 +19,15 @@ def example():
     )
 
 
-__func__ = st_toggle_switch  # main function of your extra!
 __title__ = "Toggle Switch"  # title of your extra!
 __desc__ = (
-    "On/Off Toggle Switch with color custimizations"  # description of your extra!
+    "On/Off Toggle Switch with color customizations"  # description of your extra!
 )
 __icon__ = "🔛"  # give your extra an icon!
 __examples__ = [example]  # create some examples to show how cool your extra is!
 __author__ = "Carlos D. Serrano"
-__pypi_name__ = "streamlit-toggle_switch"
+__pypi_name__ = "streamlit-toggle-switch"
 __package_name__ = "streamlit_toggle"
 __github_repo__ = "sqlinsights/streamlit-toggle-switch"  # Optional
+__forum_url__ = "https://discuss.streamlit.io/t/streamlit-toggle-switch/32474"
 __experimental_playground__ = False  # Optional
